@@ -17,9 +17,9 @@
  * under the License.
  */
 import React from 'react';
-import { t, styled, supersetTheme } from '@superset-ui/core';
+import { t, styled, useTheme } from '@superset-ui/core';
 
-import { Menu } from 'src/common/components';
+import { Menu } from 'src/components/Menu';
 import Button, { ButtonProps } from 'src/components/Button';
 import Icons from 'src/components/Icons';
 import {
@@ -93,6 +93,8 @@ const RunQueryActionButton = ({
   runQuery,
   stopQuery,
 }: Props) => {
+  const theme = useTheme();
+
   const shouldShowStopBtn =
     !!queryState && ['running', 'pending'].indexOf(queryState) > -1;
 
@@ -123,8 +125,8 @@ const RunQueryActionButton = ({
                 <Icons.CaretDown
                   iconColor={
                     isDisabled
-                      ? supersetTheme.colors.grayscale.base
-                      : supersetTheme.colors.grayscale.light5
+                      ? theme.colors.grayscale.base
+                      : theme.colors.grayscale.light5
                   }
                   name="caret-down"
                 />
