@@ -99,8 +99,8 @@ function TemplateParamsEditor({
           title={t('Edit template parameters')}
           trigger={['hover']}
         >
-          <div role="button">
-            {`${t('Parameters')} `}
+          <div role="button" css={{ width: 'inherit' }}>
+            {t('Parameters ')}
             <Badge count={paramCount} />
             {!isValid && (
               <InfoTooltipWithTrigger
