@@ -17,6 +17,12 @@
  * under the License.
  */
 import { DatePicker as AntdDatePicker } from 'antd';
+import { styled } from '@superset-ui/core';
+
+const AntdRangePicker = AntdDatePicker.RangePicker;
+
+export const RangePicker = styled(AntdRangePicker)`
+  border-radius: ${({ theme }) => theme.gridUnit}px;
+`;
 
-export const { RangePicker } = AntdDatePicker;
 export const DatePicker = AntdDatePicker;
