@@ -18,11 +18,11 @@
  */
 import React from 'react';
 import PropTypes from 'prop-types';
-
+import { styled, t } from '@superset-ui/core';
+import { EmptyStateBig } from 'src/components/EmptyState';
 import { componentShape } from '../util/propShapes';
 import DashboardComponent from '../containers/DashboardComponent';
 import DragDroppable from './dnd/DragDroppable';
-
 import { GRID_GUTTER_SIZE, GRID_COLUMN_COUNT } from '../util/constants';
 
 const propTypes = {
@@ -48,6 +48,14 @@ const renderDraggableContentTop = dropProps =>
     <div className="drop-indicator drop-indicator--top" />
   );
 
+const DashboardEmptyStateContainer = styled.div`
+  position: absolute;
+  top: 0;
+  bottom: 0;
+  left: 0;
+  right: 0;
+`;
+
 class DashboardGrid extends React.PureComponent {
   constructor(props) {
     super(props);
@@ -140,82 +148,100 @@ class DashboardGrid extends React.PureComponent {
     const { isResizing, rowGuideTop } = this.state;
 
     return width < 100 ? null : (
-      <div className="dashboard-grid" ref={this.setGridRef}>
-        <div className="grid-content" data-test="grid-content">
-          {/* make the area above components droppable */}
-          {editMode && (
-            <DragDroppable
-              component={gridComponent}
-              depth={depth}
-              parentComponent={null}
-              index={0}
-              orientation="column"
-              onDrop={this.handleTopDropTargetDrop}
-              className="empty-droptarget"
-              editMode
-            >
-              {renderDraggableContentBottom}
-            </DragDroppable>
-          )}
-
-          {gridComponent?.children?.map((id, index) => (
-            <DashboardComponent
-              key={id}
-              id={id}
-              parentId={gridComponent.id}
-              depth={depth + 1}
-              index={index}
-              availableColumnCount={GRID_COLUMN_COUNT}
-              columnWidth={columnWidth}
-              isComponentVisible={isComponentVisible}
-              onResizeStart={this.handleResizeStart}
-              onResize={this.handleResize}
-              onResizeStop={this.handleResizeStop}
-              onChangeTab={this.handleChangeTab}
-            />
-          ))}
-
-          {/* make the area below components droppable */}
-          {editMode && gridComponent?.children?.length > 0 && (
-            <DragDroppable
-              component={gridComponent}
-              depth={depth}
-              parentComponent={null}
-              index={gridComponent.children.length}
-              orientation="column"
-              onDrop={handleComponentDrop}
-              className="empty-droptarget"
-              editMode
-            >
-              {renderDraggableContentTop}
-            </DragDroppable>
-          )}
-
-          {isResizing &&
-            Array(GRID_COLUMN_COUNT)
-              .fill(null)
-              .map((_, i) => (
-                <div
-                  key={`grid-column-${i}`}
-                  className="grid-column-guide"
-                  style={{
-                    left: i * GRID_GUTTER_SIZE + i * columnWidth,
-                    width: columnWidth,
-                  }}
-                />
-              ))}
-
-          {isResizing && rowGuideTop && (
-            <div
-              className="grid-row-guide"
-              style={{
-                top: rowGuideTop,
-                width,
+      <>
+        {editMode && gridComponent?.children?.length === 0 && (
+          <DashboardEmptyStateContainer>
+            <EmptyStateBig
+              title={t('Drag and drop components and charts to the dashboard')}
+              description={t(
+                'You can create new charts or use existing ones from the panel on the right',
+              )}
+              buttonText={
+                <>
+                  <i className="fa fa-plus" />
+                  {t('Create a new chart')}
+                </>
+              }
+              buttonAction={() => {
+                window.location.assign('/chart/add');
               }}
+              image="chart.svg"
             />
-          )}
+          </DashboardEmptyStateContainer>
+        )}
+        <div className="dashboard-grid" ref={this.setGridRef}>
+          <div className="grid-content" data-test="grid-content">
+            {/* make the area above components droppable */}
+            {editMode && (
+              <DragDroppable
+                component={gridComponent}
+                depth={depth}
+                parentComponent={null}
+                index={0}
+                orientation="column"
+                onDrop={this.handleTopDropTargetDrop}
+                className="empty-droptarget"
+                editMode
+              >
+                {renderDraggableContentBottom}
+              </DragDroppable>
+            )}
+            {gridComponent?.children?.map((id, index) => (
+              <DashboardComponent
+                key={id}
+                id={id}
+                parentId={gridComponent.id}
+                depth={depth + 1}
+                index={index}
+                availableColumnCount={GRID_COLUMN_COUNT}
+                columnWidth={columnWidth}
+                isComponentVisible={isComponentVisible}
+                onResizeStart={this.handleResizeStart}
+                onResize={this.handleResize}
+                onResizeStop={this.handleResizeStop}
+                onChangeTab={this.handleChangeTab}
+              />
+            ))}
+            {/* make the area below components droppable */}
+            {editMode && gridComponent?.children?.length > 0 && (
+              <DragDroppable
+                component={gridComponent}
+                depth={depth}
+                parentComponent={null}
+                index={gridComponent.children.length}
+                orientation="column"
+                onDrop={handleComponentDrop}
+                className="empty-droptarget"
+                editMode
+              >
+                {renderDraggableContentTop}
+              </DragDroppable>
+            )}
+            {isResizing &&
+              Array(GRID_COLUMN_COUNT)
+                .fill(null)
+                .map((_, i) => (
+                  <div
+                    key={`grid-column-${i}`}
+                    className="grid-column-guide"
+                    style={{
+                      left: i * GRID_GUTTER_SIZE + i * columnWidth,
+                      width: columnWidth,
+                    }}
+                  />
+                ))}
+            {isResizing && rowGuideTop && (
+              <div
+                className="grid-row-guide"
+                style={{
+                  top: rowGuideTop,
+                  width,
+                }}
+              />
+            )}
+          </div>
         </div>
-      </div>
+      </>
     );
   }
 }
