@@ -25,24 +25,32 @@ import {
   waitFor,
 } from 'spec/helpers/testing-library';
 import { mockStoreWithChartsInTabsAndRoot } from 'spec/fixtures/mockStore';
-import { Form, FormInstance } from 'src/common/components';
+import { AntdForm, FormInstance } from 'src/components';
 import { NativeFiltersForm } from 'src/dashboard/components/nativeFilters/FiltersConfigModal/types';
-import FiltersConfigForm from 'src/dashboard/components/nativeFilters/FiltersConfigModal/FiltersConfigForm/FiltersConfigForm';
+import FiltersConfigForm, {
+  FilterPanels,
+} from 'src/dashboard/components/nativeFilters/FiltersConfigModal/FiltersConfigForm/FiltersConfigForm';
 
 describe('FilterScope', () => {
   const save = jest.fn();
   let form: FormInstance<NativeFiltersForm>;
   const mockedProps = {
     filterId: 'DefaultFilterId',
-    restoreFilter: jest.fn(),
+    dependencies: [],
     setErroredFilters: jest.fn(),
-    parentFilters: [],
+    restoreFilter: jest.fn(),
+    getAvailableFilters: () => [],
+    getDependencySuggestion: () => '',
     save,
     removedFilters: {},
+    handleActiveFilterPanelChange: jest.fn(),
+    activeFilterPanelKeys: `DefaultFilterId-${FilterPanels.configuration.key}`,
+    isActive: true,
+    validateDependencies: jest.fn(),
   };
 
   const MockModal = ({ scope }: { scope?: object }) => {
-    const [newForm] = Form.useForm<NativeFiltersForm>();
+    const [newForm] = AntdForm.useForm<NativeFiltersForm>();
     form = newForm;
     if (scope) {
       form.setFieldsValue({
@@ -55,9 +63,9 @@ describe('FilterScope', () => {
     }
     return (
       <Provider store={mockStoreWithChartsInTabsAndRoot}>
-        <Form form={form}>
+        <AntdForm form={form}>
           <FiltersConfigForm form={form} {...mockedProps} />
-        </Form>
+        </AntdForm>
       </Provider>
     );
   };
