@@ -17,29 +17,27 @@
  * under the License.
  */
 import {
-  ExtraFormData,
-  QueryFormData,
-  getChartMetadataRegistry,
+  AdhocFilter,
   Behavior,
+  DataMaskStateWithId,
   EXTRA_FORM_DATA_APPEND_KEYS,
   EXTRA_FORM_DATA_OVERRIDE_KEYS,
-  AdhocFilter,
+  ExtraFormData,
   FeatureFlag,
+  Filter,
+  getChartMetadataRegistry,
+  QueryFormData,
 } from '@superset-ui/core';
 import { Charts, DashboardLayout } from 'src/dashboard/types';
-import { RefObject } from 'react';
-import { DataMaskStateWithId } from 'src/dataMask/types';
 import extractUrlParams from 'src/dashboard/util/extractUrlParams';
 import { isFeatureEnabled } from 'src/featureFlags';
-import { Filter } from './types';
 import { CHART_TYPE, TAB_TYPE } from '../../util/componentTypes';
 import { DASHBOARD_GRID_ID, DASHBOARD_ROOT_ID } from '../../util/constants';
 
 export const getFormData = ({
   datasetId,
-  cascadingFilters = {},
+  dependencies = {},
   groupby,
-  inputRef,
   defaultDataMask,
   controlValues,
   filterType,
@@ -50,8 +48,7 @@ export const getFormData = ({
   type,
 }: Partial<Filter> & {
   datasetId?: number;
-  inputRef?: RefObject<HTMLInputElement>;
-  cascadingFilters?: object;
+  dependencies?: object;
   groupby?: string;
   adhoc_filters?: AdhocFilter[];
   time_range?: string;
@@ -75,7 +72,7 @@ export const getFormData = ({
     ...otherProps,
     adhoc_filters: adhoc_filters ?? [],
     extra_filters: [],
-    extra_form_data: cascadingFilters,
+    extra_form_data: dependencies,
     granularity_sqla,
     metrics: ['count'],
     row_limit: 1000,
@@ -86,7 +83,6 @@ export const getFormData = ({
     url_params: extractUrlParams('regular'),
     inView: true,
     viz_type: filterType,
-    inputRef,
     type,
   };
 };
