@@ -17,8 +17,10 @@
  * under the License.
  */
 import React, { ReactNode, useCallback, useState } from 'react';
-import { ControlType } from '@superset-ui/chart-controls';
-import { ControlComponentProps as BaseControlComponentProps } from '@superset-ui/chart-controls/lib/shared-controls/components/types';
+import {
+  ControlType,
+  ControlComponentProps as BaseControlComponentProps,
+} from '@superset-ui/chart-controls';
 import { JsonValue, QueryFormData } from '@superset-ui/core';
 import ErrorBoundary from 'src/components/ErrorBoundary';
 import { ExploreActions } from 'src/explore/actions/exploreActions';
@@ -47,9 +49,8 @@ export type ControlProps = {
 /**
  *
  */
-export type ControlComponentProps<
-  ValueType extends JsonValue = JsonValue
-> = Omit<ControlProps, 'value'> & BaseControlComponentProps<ValueType>;
+export type ControlComponentProps<ValueType extends JsonValue = JsonValue> =
+  Omit<ControlProps, 'value'> & BaseControlComponentProps<ValueType>;
 
 export default function Control(props: ControlProps) {
   const {
