@@ -17,7 +17,7 @@
  * under the License.
  */
 
-import { styled, css, SupersetTheme } from '@superset-ui/core';
+import { css, styled, SupersetTheme } from '@superset-ui/core';
 import { JsonEditor } from 'src/components/AsyncAceEditor';
 import Button from 'src/components/Button';
 
@@ -62,7 +62,6 @@ export const StyledFormHeader = styled.header`
 
   h4 {
     color: ${({ theme }) => theme.colors.grayscale.dark2};
-    font-weight: bold;
     font-size: ${({ theme }) => theme.typography.sizes.l}px;
     margin: 0;
     padding: 0;
@@ -95,7 +94,6 @@ export const antdCollapseStyles = (theme: SupersetTheme) => css`
   }
   h4 {
     font-size: 16px;
-    font-weight: bold;
     margin-top: 0;
     margin-bottom: ${theme.gridUnit}px;
   }
@@ -155,10 +153,6 @@ export const antDModalStyles = (theme: SupersetTheme) => css`
     opacity: 1;
   }
 
-  .ant-modal-title > h4 {
-    font-weight: bold;
-  }
-
   .ant-modal-body {
     height: ${theme.gridUnit * 180.5}px;
   }
@@ -176,7 +170,7 @@ export const antDAlertStyles = (theme: SupersetTheme) => css`
   .ant-alert-message {
     color: ${theme.colors.info.dark2};
     font-size: ${theme.typography.sizes.s + 1}px;
-    font-weight: bold;
+    font-weight: ${theme.typography.weights.bold};
   }
 
   .ant-alert-description {
@@ -198,7 +192,9 @@ export const antDAlertStyles = (theme: SupersetTheme) => css`
 `;
 
 export const StyledAlertMargin = styled.div`
-  margin: 0 ${({ theme }) => theme.gridUnit * 4}px -${({ theme }) => theme.gridUnit * 4}px;
+  ${({ theme }) => css`
+    margin: 0 ${theme.gridUnit * 4}px -${theme.gridUnit * 4}px;
+  `}
 `;
 
 export const antDErrorAlertStyles = (theme: SupersetTheme) => css`
@@ -208,7 +204,7 @@ export const antDErrorAlertStyles = (theme: SupersetTheme) => css`
   color: ${theme.colors.error.dark2};
   .ant-alert-message {
     font-size: ${theme.typography.sizes.s + 1}px;
-    font-weight: bold;
+    font-weight: ${theme.typography.weights.bold};
   }
   .ant-alert-description {
     font-size: ${theme.typography.sizes.s + 1}px;
@@ -284,85 +280,86 @@ export const validatedFormStyles = (theme: SupersetTheme) => css`
 `;
 
 export const StyledInputContainer = styled.div`
-  margin-bottom: ${({ theme }) => theme.gridUnit * 6}px;
-  &.mb-0 {
-    margin-bottom: 0;
-  }
-  &.mb-8 {
-    margin-bottom: ${({ theme }) => theme.gridUnit * 2}px;
-  }
-
-  .control-label {
-    color: ${({ theme }) => theme.colors.grayscale.dark1};
-    font-size: ${({ theme }) => theme.typography.sizes.s - 1}px;
-    margin-bottom: ${({ theme }) => theme.gridUnit * 2}px;
-  }
-
-  &.extra-container {
-    padding-top: 8px;
-  }
-
-  .input-container {
-    display: flex;
-    align-items: top;
-
-    label {
-      display: flex;
-      margin-left: ${({ theme }) => theme.gridUnit * 2}px;
-      margin-top: ${({ theme }) => theme.gridUnit * 0.75}px;
-      font-family: ${({ theme }) => theme.typography.families.sansSerif};
-      font-size: ${({ theme }) => theme.typography.sizes.m}px;
-    }
-
-    i {
-      margin: 0 ${({ theme }) => theme.gridUnit}px;
-    }
-  }
-
-  input,
-  textarea {
-    flex: 1 1 auto;
-  }
-
-  textarea {
-    height: 160px;
-    resize: none;
-  }
-
-  input::placeholder,
-  textarea::placeholder {
-    color: ${({ theme }) => theme.colors.grayscale.light1};
-  }
-
-  textarea,
-  input[type='text'],
-  input[type='number'] {
-    padding: ${({ theme }) => theme.gridUnit * 1.5}px
-      ${({ theme }) => theme.gridUnit * 2}px;
-    border-style: none;
-    border: 1px solid ${({ theme }) => theme.colors.grayscale.light2};
-    border-radius: ${({ theme }) => theme.gridUnit}px;
-
-    &[name='name'] {
-      flex: 0 1 auto;
-      width: 40%;
-    }
-  }
-  &.expandable {
-    height: 0;
-    overflow: hidden;
-    transition: height 0.25s;
-    margin-left: ${({ theme }) => theme.gridUnit * 8}px;
-    margin-bottom: 0;
-    padding: 0;
-    .control-label {
+  ${({ theme }) => css`
+    margin-bottom: ${theme.gridUnit * 6}px;
+    &.mb-0 {
       margin-bottom: 0;
     }
-    &.open {
-      height: ${CTAS_CVAS_SCHEMA_FORM_HEIGHT}px;
-      padding-right: ${({ theme }) => theme.gridUnit * 5}px;
+    &.mb-8 {
+      margin-bottom: ${theme.gridUnit * 2}px;
     }
-  }
+
+    .control-label {
+      color: ${theme.colors.grayscale.dark1};
+      font-size: ${theme.typography.sizes.s - 1}px;
+      margin-bottom: ${theme.gridUnit * 2}px;
+    }
+
+    &.extra-container {
+      padding-top: ${theme.gridUnit * 2}px;
+    }
+
+    .input-container {
+      display: flex;
+      align-items: top;
+
+      label {
+        display: flex;
+        margin-left: ${theme.gridUnit * 2}px;
+        margin-top: ${theme.gridUnit * 0.75}px;
+        font-family: ${theme.typography.families.sansSerif};
+        font-size: ${theme.typography.sizes.m}px;
+      }
+
+      i {
+        margin: 0 ${theme.gridUnit}px;
+      }
+    }
+
+    input,
+    textarea {
+      flex: 1 1 auto;
+    }
+
+    textarea {
+      height: 160px;
+      resize: none;
+    }
+
+    input::placeholder,
+    textarea::placeholder {
+      color: ${theme.colors.grayscale.light1};
+    }
+
+    textarea,
+    input[type='text'],
+    input[type='number'] {
+      padding: ${theme.gridUnit * 1.5}px ${theme.gridUnit * 2}px;
+      border-style: none;
+      border: 1px solid ${theme.colors.grayscale.light2};
+      border-radius: ${theme.gridUnit}px;
+
+      &[name='name'] {
+        flex: 0 1 auto;
+        width: 40%;
+      }
+    }
+    &.expandable {
+      height: 0;
+      overflow: hidden;
+      transition: height 0.25s;
+      margin-left: ${theme.gridUnit * 8}px;
+      margin-bottom: 0;
+      padding: 0;
+      .control-label {
+        margin-bottom: 0;
+      }
+      &.open {
+        height: ${CTAS_CVAS_SCHEMA_FORM_HEIGHT}px;
+        padding-right: ${theme.gridUnit * 5}px;
+      }
+    }
+  `}
 `;
 
 export const StyledJsonEditor = styled(JsonEditor)`
@@ -397,13 +394,13 @@ export const StyledAlignment = styled.div`
 `;
 
 export const buttonLinkStyles = (theme: SupersetTheme) => css`
-  font-weight: 400;
+  font-weight: ${theme.typography.weights.normal};
   text-transform: initial;
   padding-right: ${theme.gridUnit * 2}px;
 `;
 
 export const alchemyButtonLinkStyles = (theme: SupersetTheme) => css`
-  font-weight: 400;
+  font-weight: ${theme.typography.weights.normal};
   text-transform: initial;
   padding: ${theme.gridUnit * 8}px 0 0;
   margin-left: 0px;
@@ -424,7 +421,7 @@ export const TabHeader = styled.div`
 
 export const CreateHeaderTitle = styled.div`
   color: ${({ theme }) => theme.colors.grayscale.dark2};
-  font-weight: bold;
+  font-weight: ${({ theme }) => theme.typography.weights.bold};
   font-size: ${({ theme }) => theme.typography.sizes.m}px;
 `;
 
@@ -442,7 +439,7 @@ export const EditHeaderTitle = styled.div`
 export const EditHeaderSubtitle = styled.div`
   color: ${({ theme }) => theme.colors.grayscale.dark1};
   font-size: ${({ theme }) => theme.typography.sizes.l}px;
-  font-weight: bold;
+  font-weight: ${({ theme }) => theme.typography.weights.bold};
 `;
 
 export const CredentialInfoForm = styled.div`
@@ -515,7 +512,7 @@ export const SelectDatabaseStyles = styled.div`
     margin: ${({ theme }) => theme.gridUnit * 4}px;
     .available-label {
       font-size: ${({ theme }) => theme.typography.sizes.l * 1.1}px;
-      font-weight: bold;
+      font-weight: ${({ theme }) => theme.typography.weights.bold};
       margin: ${({ theme }) => theme.gridUnit * 6}px 0;
     }
     .available-select {
@@ -555,7 +552,7 @@ export const StyledCatalogTable = styled.div`
 
   .gsheet-title {
     font-size: ${({ theme }) => theme.typography.sizes.l * 1.1}px;
-    font-weight: bold;
+    font-weight: ${({ theme }) => theme.typography.weights.bold};
     margin: ${({ theme }) => theme.gridUnit * 10}px 0 16px;
   }
 
