@@ -34,7 +34,7 @@ from superset.connectors.base.views import BS3TextFieldROWidget, DatasourceModel
 from superset.connectors.connector_registry import ConnectorRegistry
 from superset.connectors.druid import models
 from superset.constants import RouteMethod
-from superset.typing import FlaskResponse
+from superset.superset_typing import FlaskResponse
 from superset.utils import core as utils
 from superset.views.base import (
     BaseSupersetView,
@@ -62,7 +62,9 @@ class EnsureEnabledMixin:
 
 
 class DruidColumnInlineView(  # pylint: disable=too-many-ancestors
-    CompactCRUDMixin, EnsureEnabledMixin, SupersetModelView,
+    CompactCRUDMixin,
+    EnsureEnabledMixin,
+    SupersetModelView,
 ):
     datamodel = SQLAInterface(models.DruidColumn)
     include_route_methods = RouteMethod.RELATED_VIEW_SET
@@ -151,7 +153,9 @@ class DruidColumnInlineView(  # pylint: disable=too-many-ancestors
 
 
 class DruidMetricInlineView(  # pylint: disable=too-many-ancestors
-    CompactCRUDMixin, EnsureEnabledMixin, SupersetModelView,
+    CompactCRUDMixin,
+    EnsureEnabledMixin,
+    SupersetModelView,
 ):
     datamodel = SQLAInterface(models.DruidMetric)
     include_route_methods = RouteMethod.RELATED_VIEW_SET
@@ -206,7 +210,10 @@ class DruidMetricInlineView(  # pylint: disable=too-many-ancestors
 
 
 class DruidClusterModelView(  # pylint: disable=too-many-ancestors
-    EnsureEnabledMixin, SupersetModelView, DeleteMixin, YamlExportMixin,
+    EnsureEnabledMixin,
+    SupersetModelView,
+    DeleteMixin,
+    YamlExportMixin,
 ):
     datamodel = SQLAInterface(models.DruidCluster)
     include_route_methods = RouteMethod.CRUD_SET
@@ -270,7 +277,10 @@ class DruidClusterModelView(  # pylint: disable=too-many-ancestors
 
 
 class DruidDatasourceModelView(  # pylint: disable=too-many-ancestors
-    EnsureEnabledMixin, DatasourceModelView, DeleteMixin, YamlExportMixin,
+    EnsureEnabledMixin,
+    DatasourceModelView,
+    DeleteMixin,
+    YamlExportMixin,
 ):
     datamodel = SQLAInterface(models.DruidDatasource)
     include_route_methods = RouteMethod.CRUD_SET
