@@ -110,6 +110,8 @@ FRONTEND_CONF_KEYS = (
     "CSV_EXTENSIONS",
     "COLUMNAR_EXTENSIONS",
     "ALLOWED_EXTENSIONS",
+    "HTML_SANITIZATION",
+    "HTML_SANITIZATION_SCHEMA_EXTENSIONS",
 )
 
 logger = logging.getLogger(__name__)
