@@ -24,7 +24,7 @@ from sqlalchemy.sql import func
 import tests.integration_tests.test_app
 from superset import db
 from superset.models.core import CssTemplate
-from superset.utils.core import get_example_database
+from superset.utils.database import get_example_database
 
 from tests.integration_tests.base_tests import SupersetTestCase
 
@@ -34,7 +34,10 @@ CSS_TEMPLATES_FIXTURE_COUNT = 5
 
 class TestCssTemplateApi(SupersetTestCase):
     def insert_css_template(
-        self, template_name: str, css: str, created_by_username: str = "admin",
+        self,
+        template_name: str,
+        css: str,
+        created_by_username: str = "admin",
     ) -> CssTemplate:
         admin = self.get_user(created_by_username)
         css_template = CssTemplate(
