@@ -19,7 +19,7 @@ from .birth_names_dashboard import (
     load_birth_names_dashboard_with_slices,
     load_birth_names_dashboard_with_slices_module_scope,
 )
-from .energy_dashboard import load_energy_table_with_slice
+from .energy_dashboard import load_energy_table_data, load_energy_table_with_slice
 from .public_role import public_role_like_gamma, public_role_like_test_role
 from .unicode_dashboard import (
     load_unicode_dashboard_with_position,
