@@ -373,7 +373,7 @@ dataset_config: Dict[str, Any] = {
     "template_params": {},
     "filter_select_enabled": True,
     "fetch_values_predicate": None,
-    "extra": "dttm > sysdate() -10 ",
+    "extra": '{ "certification": { "certified_by": "Data Platform Team", "details": "This table is the source of truth." }, "warning_markdown": "This is a warning." }',
     "metrics": [
         {
             "metric_name": "count",
@@ -449,7 +449,7 @@ chart_config: Dict[str, Any] = {
     "dataset_uuid": "10808100-158b-42c4-842e-f32b99d88dfb",
 }
 
-dashboard_config = {
+dashboard_config: Dict[str, Any] = {
     "dashboard_title": "Test dash",
     "description": None,
     "css": "",
@@ -492,7 +492,9 @@ dashboard_config = {
     },
     "metadata": {
         "timed_refresh_immune_slices": [83],
-        "filter_scopes": {"83": {"region": {"scope": ["ROOT_ID"], "immune": [83]}},},
+        "filter_scopes": {
+            "83": {"region": {"scope": ["ROOT_ID"], "immune": [83]}},
+        },
         "expanded_slices": {"83": True},
         "refresh_frequency": 0,
         "default_filters": "{}",
